@@ -2,8 +2,7 @@
 package Docserver::Config;
 %Docserver::Config::Config =
 	(
-	'port'		=>	2324,
-	### 'port'		=>	5455,
+	'port'		=>	5455,
 	'clients'	=>	[
 					{
 					'mask' => '^127\.0\.0\.1$',
@@ -20,7 +19,12 @@ package Docserver::Config;
 	'ps'		=>	'Generic PostScript Printer on FILE:',
 	### 'ps'		=> 	'Adobe Generic PS on FILE:',
 	'ps1'		=>	'Adobe Generic PS1 on FILE:',
+	'excel.ps'	=>	'Adobe Generic PS na FILE:',
+	'excel.ps1'	=>	'Adobe Generic PS1 na FILE:',
+	# Excel variants are here in case Excel names differ from the
+	# Word ones. If they are not here, base ps and ps1 will be
+	# used.
 	'pidfile'	=>	'docserver.pid',
-	'logfile'	=>	'docserver.log',
+	'logfile'	=>	1,
 	);
 
